@@ -65,14 +65,16 @@ var getAlarms = async (searchTerms) => {
   const states = [];
   try {
     const alarmsForAccountAndRegion = await getCloudwatchAlarms();
-    const alarms = hasAlarmMatching(alarmsForAccountAndRegion, searchTerms).map(
-      (alarm) => {
-        alarm.reason = `${alarm.alarmArn} in ${alarm.state} due to ${alarm.reason}`;
-        return alarm;
-      }
+    states.push(
+      ...hasAlarmMatching(alarmsForAccountAndRegion, searchTerms).map(
+        (alarm) => {
+          alarm.reason = `${alarm.alarmArn} in ${alarm.state} due to ${alarm.reason}`;
+          return alarm;
+        }
+      )
     );
-    if (alarms.length === 0) {
-      alarms.push({
+    if (states.length === 0) {
+      states.push({
         state: "ALARM" /* ALARM */,
         reason: `No alarms were found for the provided search terms: ${searchTerms.join(
           ", "
@@ -96,14 +98,16 @@ var getAggregateAlarmState = async (searchTerms) => {
   };
 };
 var hasAlarmMatching = (alarms, searchTerms) => {
-  return alarms.flatMap(
-    (alarm) => searchTerms.map((searchTerm) => {
-      var _a;
-      return ((_a = alarm.alarmDescription) == null ? void 0 : _a.includes(searchTerm)) ? alarm : void 0;
-    }).filter((sameAlarm) => sameAlarm)
-  ).filter(
-    (sameAlarm, index) => alarms.indexOf(sameAlarm) === index
-  );
+  return [
+    ...new Set(
+      alarms.flatMap(
+        (alarm) => searchTerms.map((searchTerm) => {
+          var _a;
+          return ((_a = alarm.alarmDescription) == null ? void 0 : _a.includes(searchTerm)) ? alarm : void 0;
+        }).filter((sameAlarm) => sameAlarm)
+      )
+    )
+  ];
 };
 
 // src/time-windows/change-controller/calendar-state.ts
